import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

// A class designed to be extended in order to write simple GUI
// programs.  It provides a very small subset of the functions
// supported by the Squint GUIManager
public class ComponentManager extends JFrame implements ActionListener, ContainerListener
{
    // Make it easier to access the content pane
    public Container contentPane;
    
    public ComponentManager() {
    }     

    // Create the user interface window
    public void createWindow( int width, int height ) {
        this.setSize( width, height );
        this.setVisible( true );
        contentPane = this.getContentPane();
        contentPane.setLayout( new FlowLayout() );
        contentPane.addContainerListener( this );
    }
    
    public void componentAdded( ContainerEvent ev ) {
        Component comp = ev.getChild();
        if ( comp instanceof JButton ) {
            ((JButton) comp).addActionListener( this );
        } else if ( comp instanceof JPanel ) {
            ((JPanel) comp).addContainerListener( this );
        }
        ev.getContainer().validate();
    }
    
    public void componentRemoved( ContainerEvent ev ) {
    
    }

    // Invoke method to respond when user clicks the buttons
    public void actionPerformed( ActionEvent e ) {
        Component source = (Component ) e.getSource();
        if ( source instanceof JButton ) {
            this.buttonClicked( (JButton) source );
        }
        validate();
    }
    
    // A placehoder for an event handling method that
    // may be defined when MiniManager is extended
    public void buttonClicked( JButton which ) {
        buttonClicked();
    }
    
    // A placehoder for an event handling method that
    // may be defined when MiniManager is extended
    public void buttonClicked(  ) {
        // Do nothing
    }
}
