import java.net.*;
import java.io.*;
import java.util.Scanner;

// A class the supports sending text messages through a TCP connection
public class MiniConnection {
    // The socket between the client and the server
    private Socket serverConnection;
    
    // Stream used to access data received from the server
    public final Scanner in;
    
    // Stream used to send data to the server
    public final PrintWriter out;
    
    // Create a connection given a machine address and port number
    public MiniConnection( String serverAddr, int port ) {
        try {
           // Create the connection
           serverConnection = new Socket( serverAddr, port );
           
           in =     // Convert the stream into a form suitable for text input
                new Scanner( new BufferedReader( new InputStreamReader(
                                              serverConnection.getInputStream())));
                     
           String sep = System.getProperty( "line.separator" );
           System.setProperty( "line.separator", "\r\n" );
        
           out =      // Convert the stream into a form suitable for text output
                new PrintWriter( new OutputStreamWriter( 
                                              serverConnection.getOutputStream()), true);
           System.setProperty( "line.separator", sep );

        } catch ( IOException e ) { // throw gentler exception if anything goes wrong
            throw new IllegalStateException( "Unable to create connection: " + e);
        }
    }
    
    
    // Close the connection
    public void close() {
        try {
            serverConnection.close();
        } catch ( IOException e ) {
            throw new IllegalStateException( "Error closing connection: " + e );
        }
    }
}
