import javax.swing.*;
import java.net.*;

public class SMTPClient extends ComponentManager
{
   // Change these values to adjust the size of the program's window
   private final int WINDOW_WIDTH  = 450;
   private final int WINDOW_HEIGHT = 500;
   
   // amount of space to allow in a text field for an email address
   private final int ADDR_WIDTH = 14;
   
   // amount of space to allow in a text field for message subject
   private final int SUBJECT_WIDTH = 30;
   
   // how many characters wide program's text areas should be
   private final int AREA_WIDTH = 35;
   
   // how many lines tall the message area should be
   private final int MESSAGE_LINES = 15;
   
   // how many lines tall the log area should be
   private final int LOG_LINES = 5;

   // address of SMTP server to use
   private final String SMTP_SERVER = "cs.williams.edu";
   
   // Standard port for connection to an SMTP server
   private final int SMTP_PORT = 25;

   // Fields from to and from addresses, and the subject
   private JTextField from = new JTextField( ADDR_WIDTH );
   private JTextField to = new JTextField( ADDR_WIDTH );
   private JTextField subject = new JTextField( SUBJECT_WIDTH );
   
   // Area in which user can type message body
   private JTextArea message = new JTextArea( MESSAGE_LINES, AREA_WIDTH );
   
   // Area in which responses from server will be logged
   private JTextArea log = new JTextArea( LOG_LINES, AREA_WIDTH );
   
  /**
   * Place fields and text areas on screen to enable user to
   * enter mail together with a send button.
   */
   public void init() {
      // Create window to hold all the components
      this.createWindow( WINDOW_WIDTH, WINDOW_HEIGHT );
      
      JPanel curPane = new JPanel( );
      
      curPane.add( new JLabel( "From" ) );
      curPane.add( to );
      contentPane.add( curPane );
      
      curPane = new JPanel( ); 
      curPane.add( new JLabel( "To:" ) );
      curPane.add( from );
      contentPane.add( curPane );

      curPane = new JPanel( ); 
      curPane.add( new JLabel( "Subject:" ) );
      curPane.add( subject );
      contentPane.add( curPane );
      
      contentPane.add ( new JLabel( "Enter your message below") );
      
      contentPane.add( new JScrollPane( message ) );
      
      contentPane.add( new JButton( "Send" ) );
      
      contentPane.add( new JScrollPane( log ) );
      log.setEditable( false );
}

   /*
    * Send a single email message to an SMTP server
    */
    public void buttonClicked(  ) {
       MiniConnection toServer = new MiniConnection( SMTP_SERVER, SMTP_PORT );
       
       log.append( toServer.in.nextLine() + "\n" );
       
       try {
           toServer.out.println( "HELO " + InetAddress.getLocalHost().getHostName() );
        } catch ( UnknownHostException e ) { }
        log.append( toServer.in.nextLine() + "\n" );
       
        toServer.out.println( "MAIL FROM: <" + from.getText() +">" );
        log.append( toServer.in.nextLine() + "\n" );
       
        toServer.out.println( "RCPT TO: <" + to.getText() +">" );
        log.append( toServer.in.nextLine() + "\n" );
        
        toServer.out.println( "DATA" );
        log.append( toServer.in.nextLine() + "\n" );
        
        toServer.out.println( message.getText() );
        toServer.out.println( "." );
        log.append( toServer.in.nextLine() + "\n" );
        
        toServer.out.println( "QUIT" );
        log.append( toServer.in.nextLine() + "\n" );
        
        toServer.close();
        
    }
   
    public SMTPClient() {
        this.init();
    }

}
